@@ -4,7 +4,7 @@
 #include <stdio.h>
 #include "mem.h"
 
-void decrypt_file (FILE* input, int intput_file_size, FILE* output);
+void decrypt_file (FILE* input, int intput_file_size, FILE* output, int algo);
 
 #endif
 
